@@ -21,13 +21,28 @@ test_that("mlflow_create/get_experiment() basic functionality (client)", {
 
   client <- mlflow_client()
 
-  experiment_1_id <- mlflow_create_experiment(client = client, "exp_name", "art_loc")
+  experiment_1_id <- mlflow_create_experiment(
+    client = client,
+    name = "exp_name",
+    artifact_location = "art_loc",
+    tags = list(foo = "bar", foz = "baz", fiz = "biz")
+  )
   experiment_1a <- mlflow_get_experiment(client = client, experiment_id = experiment_1_id)
   experiment_1b <- mlflow_get_experiment(client = client, name = "exp_name")
 
   expect_identical(experiment_1a, experiment_1b)
   expect_identical(experiment_1a$artifact_location, "art_loc")
   expect_identical(experiment_1a$name, "exp_name")
+
+  expect_true(
+    all(purrr::transpose(experiment_1b$tags[[1]]) %in%
+      list(
+        list(key = "foz", value = "baz"),
+        list(key = "foo", value = "bar"),
+        list(key = "fiz", value = "biz")
+      )
+    )
+  )
 })
 
 test_that("mlflow_get_experiment() not found error", {
